<?php

define( 'TRUSTPILOT_MASTER_FIELD', 'master_settings_field' );
define( 'TRUSTPILOT_ORDER_DATA', 'OrderData' );
define( 'TRUSTPILOT_PAST_ORDERS_FIELD', 'trustpilot_past_orders' );
define( 'TRUSTPILOT_FAILED_ORDERS_FIELD', 'trustpilot_failed_orders' );
define( 'TRUSTPILOT_PLUGIN_STATUS', 'trustpilot_plugin_status' );
define( 'TRUSTPILOT_GENERAL_CONFIGURATION', 'general' );
define( 'TRUSTPILOT_TRUSTBOX_CONFIGURATION', 'trustbox' );
define( 'TRUSTPILOT_INTEGRATION_KEY', 'key' );
define( 'TRUSTPILOT_PLUGIN_VERSION', '2.5.925' );
define( 'TRUSTPILOT_SCRIPT', 'TrustpilotScriptUrl' );
define( 'TRUSTPILOT_INTEGRATION_APP', 'IntegrationAppUrl' );
define( 'TRUSTPILOT_WIDGET_SCRIPT', 'WidgetScriptUrl' );
define( 'TRUSTPILOT_PREVIEW_SCRIPT', 'PreviewScriptUrl' );
define( 'TRUSTPILOT_PREVIEW_CSS', 'PreviewCssUrl' );
define( 'TRUSTPILOT_WP_PREVIEW_CSS', 'PreviewWPCssUrl' );
define( 'TRUSTPILOT_PLUGIN_URL', 'https://ecommplugins-pluginrepo.trustpilot.com/woocommerce/trustpilot.zip' );
define( 'TRUSTPILOT_API_URL', 'https://invitejs.trustpilot.com/api/' );
define( 'TRUSTPILOT_SCRIPT_URL', 'https://invitejs.trustpilot.com/tp.min.js' );
define( 'TRUSTPILOT_INTEGRATION_APP_URL', '//ecommscript-integrationapp.trustpilot.com' );
define( 'TRUSTPILOT_WIDGET_SCRIPT_URL', '//widget.trustpilot.com/bootstrap/v5/tp.widget.bootstrap.min.js' );
define( 'TRUSTPILOT_PREVIEW_SCRIPT_URL', '//ecommplugins-scripts.trustpilot.com/v2.1/js/preview.min.js' );
define( 'TRUSTPILOT_PREVIEW_CSS_URL', '//ecommplugins-scripts.trustpilot.com/v2.1/css/preview.min.css' );
define( 'TRUSTPILOT_WP_PREVIEW_CSS_URL', '//ecommplugins-scripts.trustpilot.com/v2.1/css/preview_wp.css' );
define( 'TRUSTPILOT_IS_FROM_MARKETPLACE', 'true' );
define( 'TRUSTPILOT_TRUSTBOX_PREVIEW_URL', '//ecommplugins-trustboxpreview.trustpilot.com/v1.0/trustboxpreview.min.js' );
define( 'TRUSTPILOT_PRODUCT_ID_PREFIX', 'TRUSTPILOT_SKU_VALUE_' );
